@@ -8,12 +8,12 @@ __status__ = "Development"
 
 import numpy as np
 from scipy import constants
-from scipy.special import gamma, erf
 from scipy.misc import factorial
 from scipy import integrate
 from .particles import Molecule, MoleculeSTS
 from . import probabilities as prob
 from .errors import KineticlibError
+from math import exp, gamma, erf
 
 
 def crosssection_elastic(g: float, T: float, idata: np.ndarray, rig_sphere: bool=False) -> float:
@@ -138,7 +138,7 @@ def crosssection_diss_rigid_sphere(g: float, T: float, idata: np.ndarray, molecu
     **Note** if integrating over the crosssection, the integration must be performed not from :math:`0` to
     :math:`\\infty`, but from :math:`g_{min}` to :math:`\\infty` (because the crosssection is discontinuous),
     where :math:`g_{min}` is the minimum value of the dimensionless velocity at which the crosssection is non-zero,
-    it can be calculated using the min_dimensionless_vel_diss function
+    it can be calculated using the ``min_dimensionless_vel_diss`` function
 
     Parameters
     ----------
@@ -398,8 +398,8 @@ def vv_collisions(T: float, T1_1: float, T1_2: float, idata: np.ndarray, molecul
     """
     a = np.arange(0, molecule1.num_vibr_levels(T, T1_1, True) + 1)
     b = np.arange(0, molecule2.num_vibr_levels(T, T1_2, True) + 1)
-    vibr_exp = molecule1.vibr_exp(a, T, T1_1)
-    vibr_exp2 = molecule2.vibr_exp(b, T, T1_2)
+    vibr_exp = molecule1.vibr_exp(T, T1_1, a)
+    vibr_exp2 = molecule2.vibr_exp(T, T1_2, b)
     return raw_vv_collisions(T, idata[1], idata[0], idata[4], idata[9], idata[10],
                              molecule1.Z_vibr(T, T1_1), molecule2.Z_vibr(T, T1_2),
                              molecule1.vibr, molecule2.vibr, vibr_exp, vibr_exp2,
@@ -704,7 +704,7 @@ def raw_crosssection_diss_rigid_sphere(g: float, T: float, sigma: float, molecul
     **Note** if integrating over the crosssection, the integration must be performed not from :math:`0` to
     :math:`\\infty`, but from :math:`g_{min}` to :math:`\\infty` (because the crosssection is discontinuous),
     where :math:`g_{min}` is the minimum value of the dimensionless velocity at which the crosssection is non-zero,
-    it can be calculated using the min_dimensionless_vel_diss function
+    it can be calculated using the ``min_dimensionless_vel_diss`` function
 
     Parameters
     ----------
@@ -793,7 +793,7 @@ def elastic_omega_g_only_vss(g: float, deg: int, vsso: float) -> float:
     float
         The velocity-dependent part of the integrand of the generalized omega integral
     """
-    return np.exp(-(g ** 2)) * (g ** (3 + 2 * (deg - vsso)))
+    return exp(-(g ** 2)) * (g ** (3 + 2 * (deg - vsso)))
 
 
 def elastic_omega_g_only_rigid_sphere(g: float, deg: int) -> float:
@@ -812,7 +812,7 @@ def elastic_omega_g_only_rigid_sphere(g: float, deg: int) -> float:
     float
         The velocity-dependent part of the integrand of the generalized omega integral
     """
-    return np.exp(-(g ** 2)) * (g ** (3 + 2 * deg))
+    return exp(-(g ** 2)) * (g ** (3 + 2 * deg))
 
 
 def raw_vt_integral(T: float, deg: int, mass: float, beta: float, vssc: float, vsso: float,
@@ -1130,14 +1130,14 @@ def raw_diss_integral_rigid_sphere(T: float, deg: int, sigma: float, mass: float
             multiplier = constants.pi * (sigma ** 2) * ((0.5 / (constants.pi * mass)) ** 0.5)
 
         if deg == 0:
-            return 0.5 * multiplier * (min_sq + 1.0) * np.exp(-min_sq)
+            return 0.5 * multiplier * (min_sq + 1.0) * exp(-min_sq)
         elif deg == 1:
-            return 0.5 * multiplier * (min_sq ** 2 + 2.0 * min_sq + 2.0) * np.exp(-min_sq)
+            return 0.5 * multiplier * (min_sq ** 2 + 2.0 * min_sq + 2.0) * exp(-min_sq)
         else:
             min_g = min_sq ** 0.5
             f = lambda g: raw_crosssection_diss_rigid_sphere(g, T, sigma, molecule_vibr, molecule_diss,
                                                              center_of_mass, vl_dependent)\
-                          * (g ** (3.0 + 2.0 * deg)) * np.exp(-g ** 2)
+                          * (g ** (3.0 + 2.0 * deg)) * exp(-g ** 2)
             if not nokt:
                 return ((constants.k * T / (2 * constants.pi * mass)) ** 0.5) * integrate.quad(f, min_g, np.inf)[0]
             else:
@@ -1146,7 +1146,7 @@ def raw_diss_integral_rigid_sphere(T: float, deg: int, sigma: float, mass: float
         min_g = min_sq ** 0.5
         f = lambda g: raw_crosssection_diss_rigid_sphere(g, T, sigma, molecule_vibr, molecule_diss,
                                                          center_of_mass, vl_dependent)\
-                      * (g ** (3.0 + 2.0 * deg)) * np.exp(-g ** 2)
+                      * (g ** (3.0 + 2.0 * deg)) * exp(-g ** 2)
         if not nokt:
             return ((constants.k * T / (2 * constants.pi * mass)) ** 0.5) * integrate.quad(f, min_g, np.inf)[0]
         else:
@@ -1396,17 +1396,17 @@ def raw_dE_rot_sq(T: float, sigma: float, mass: float, vssc: float, vsso: float,
     A = constants.k * T / molecule_rot_const
     Asqrt = A ** 0.5
     molecule_num_rot_sq = molecule_num_rot * molecule_num_rot
-    prettyexp = np.exp(-(-1.0 + molecule_num_rot) * molecule_num_rot / A)
-    prettyexp2 = np.exp(0.25 * ((1.0 - 2.0 * molecule_num_rot) ** 2) / A)
-    prettyexp3 = np.exp(0.25 * ((1.0 + 2.0 * molecule_num_rot) ** 2) / A)
-    prettyexp4 = np.exp(-(1.0 + molecule_num_rot) * molecule_num_rot / A)
+    prettyexp = exp(-(-1.0 + molecule_num_rot) * molecule_num_rot / A)
+    prettyexp2 = exp(0.25 * ((1.0 - 2.0 * molecule_num_rot) ** 2) / A)
+    prettyexp3 = exp(0.25 * ((1.0 + 2.0 * molecule_num_rot) ** 2) / A)
+    prettyexp4 = exp(-(1.0 + molecule_num_rot) * molecule_num_rot / A)
     prettyerf = erf(0.5 / Asqrt)
     prettyerf2 = erf((-1.0 + 2 * molecule_num_rot) / (2.0 * Asqrt))
     prettyerf3 = erf((1.0 + 2 * molecule_num_rot) / (2.0 * Asqrt))
     prettyerf4 = erf(1.5 / Asqrt)
 
     tmp = 0.5 * A * prettyexp\
-              * (2.0 * (A - 4 * A * A + A * (5.0 + 4 * A) * np.exp((-1 + molecule_num_rot) * molecule_num_rot / A)
+              * (2.0 * (A - 4 * A * A + A * (5.0 + 4 * A) * exp((-1 + molecule_num_rot) * molecule_num_rot / A)
                         - 2.0 * A * molecule_num_rot + 2.0 * molecule_num_rot_sq - 4 * A * molecule_num_rot_sq
                         - 2.0 * molecule_num_rot_sq * molecule_num_rot_sq) + Asqrt * (-1.0 + 6.0 * A)
                  * prettyexp2 * (constants.pi ** 0.5)
@@ -1415,25 +1415,25 @@ def raw_dE_rot_sq(T: float, sigma: float, mass: float, vssc: float, vsso: float,
     tmp += 2.0 * (A ** 3) - A * prettyexp * (2.0 * A * A + 2.0 * A * (-1.0 + molecule_num_rot) * molecule_num_rot
                                              + ((-1.0 + molecule_num_rot) ** 2) * molecule_num_rot_sq)
     tmp += 0.5 * (2.0 * A * (4.0 + 9.0 * A + 2.0 * A * A) - 3.0 * (A ** 1.5)
-                  * (1.0 + 2.0 * A) * np.exp(0.25 / A) * (constants.pi ** 0.5) * prettyerf
+                  * (1.0 + 2.0 * A) * exp(0.25 / A) * (constants.pi ** 0.5) * prettyerf
                   - A * prettyexp * (2.0 * (2.0 * A * A + molecule_num_rot_sq * ((1.0 + molecule_num_rot) ** 2)
                                             + A * (3.0 + 4.0 * molecule_num_rot + 2.0 * molecule_num_rot_sq))
                                      - 3.0 * Asqrt * (1.0 + 2.0 * A) * prettyexp2 * (constants.pi ** 0.5) * prettyerf2))
 
-    tmp += 0.5 * A * (np.exp(-0.5 / A) * (2.0 * A * (1.0 + 4.0 * A)
-                                          + Asqrt * (-1.0 + 6.0 * A) * np.exp(2.25 / A) * (constants.pi ** 0.5)
+    tmp += 0.5 * A * (exp(-0.5 / A) * (2.0 * A * (1.0 + 4.0 * A)
+                                          + Asqrt * (-1.0 + 6.0 * A) * exp(2.25 / A) * (constants.pi ** 0.5)
                                           * prettyerf4)
                       - prettyexp4
                       * (8.0 * A * A + 4.0 * molecule_num_rot_sq * (-1.0 * molecule_num_rot_sq)
                          + A * (-2.0 - 4.0 * molecule_num_rot + 8.0 * molecule_num_rot_sq)
                          + Asqrt * (-1.0 + 6.0 * A) * prettyexp3 * (constants.pi ** 0.5) * prettyerf3))
     tmp += 2.0 * A * (2.0 + 2.0 * A + A * A)\
-               * np.exp(-2.0 / A) - A * prettyexp4\
+               * exp(-2.0 / A) - A * prettyexp4\
                                       * (2.0 * A * A + 2 * A * molecule_num_rot
                                              * (1.0 + molecule_num_rot)
                                          + molecule_num_rot_sq * (1.0 + molecule_num_rot) * (1.0 + molecule_num_rot))
-    tmp += 0.5 * (A * Asqrt * (1.0 + 2.0 * A) * np.exp(-2.0 / A)
-                  * (2.0 * Asqrt + 3.0 * np.exp(2.25 / A) * (constants.pi ** 0.5) * prettyerf4)
+    tmp += 0.5 * (A * Asqrt * (1.0 + 2.0 * A) * exp(-2.0 / A)
+                  * (2.0 * Asqrt + 3.0 * exp(2.25 / A) * (constants.pi ** 0.5) * prettyerf4)
                   + prettyexp4 * (-2.0 * A * (2.0 * A * A + (-1.0 + molecule_num_rot)
                                               * (-1.0 + molecule_num_rot) * molecule_num_rot_sq
                                               + A * (3.0 + 2.0 * (-2.0 + molecule_num_rot) * molecule_num_rot))
@@ -1497,19 +1497,19 @@ def raw_dE_rot_single(T: float, sigma: float, mass: float, vssc: float, vsso: fl
     """
     A = constants.k * T / molecule_rot_const
     Asqrt = A ** 0.5
-    prettyexp = np.exp(-molecule_num_rot * (molecule_num_rot - 1) / A)
+    prettyexp = exp(-molecule_num_rot * (molecule_num_rot - 1) / A)
 
     tmp = A * (A - prettyexp * (A + molecule_num_rot ** 2 - molecule_num_rot))
     tmp -= prettyexp * (A * (A + 2.0) / prettyexp - A * (A + molecule_num_rot + molecule_num_rot ** 2)
-                        + (A ** 1.5) * np.exp(((1.0 - 2.0 * molecule_num_rot) ** 2) / (4.0 * A))
+                        + (A ** 1.5) * exp(((1.0 - 2.0 * molecule_num_rot) ** 2) / (4.0 * A))
                         * (constants.pi ** 0.5) * (-erf(0.5 / Asqrt)
                                                    + erf((-1.0 + 2 * molecule_num_rot) / (2.0 * Asqrt))))
-    tmp += A * ((A + 2.0) * np.exp(-2.0 / A) - np.exp(-molecule_num_rot * (molecule_num_rot + 1) / A)
+    tmp += A * ((A + 2.0) * exp(-2.0 / A) - exp(-molecule_num_rot * (molecule_num_rot + 1) / A)
                           * (A + molecule_num_rot ** 2 + molecule_num_rot))
-    tmp -= A * (np.exp(-2.0 / A) * (A + (Asqrt * np.exp(2.25 / A)) * (constants.pi ** 0.5)
-                * erf(1.5 / Asqrt)) - np.exp(-molecule_num_rot * (1.0 + molecule_num_rot) / A)
+    tmp -= A * (exp(-2.0 / A) * (A + (Asqrt * exp(2.25 / A)) * (constants.pi ** 0.5)
+                * erf(1.5 / Asqrt)) - exp(-molecule_num_rot * (1.0 + molecule_num_rot) / A)
                 * (A + (-1.0 + molecule_num_rot) * molecule_num_rot + Asqrt
-                   * np.exp(((1.0 + 2.0 * molecule_num_rot) ** 2) / (4.0 * A))
+                   * exp(((1.0 + 2.0 * molecule_num_rot) ** 2) / (4.0 * A))
                    * (constants.pi ** 0.5) * erf((1.0 + 2.0 * molecule_num_rot) / (2.0 * Asqrt))))
     tmp *= molecule_rot_const / molecule_rot_symmetry
 
