@@ -9,6 +9,7 @@ __status__ = "Production"
 import numpy as np
 from scipy import constants
 from os.path import normcase, join, split
+from math import exp
 
 
 class Particle(object):
@@ -331,7 +332,7 @@ class MoleculeSTS(Particle):
         """
         return self.vibr[i] + self.rot[j]
 
-    def rot_exp(self, j, T: float):
+    def rot_exp(self, T: float, j):
         """Returns the rotational exponent: :math:`((2j + 1) / \\sigma_{rot}) exp(-\\varepsilon_{j} / kT)`,
         :math:`(2j + 1)`
         being the degeneracy of the j-th rotational state, and :math:`\\sigma_{rot}` being the rotational symmetry
@@ -349,7 +350,7 @@ class MoleculeSTS(Particle):
         float or 1-D np.ndarray
             The rotational exponent for a given index ``j``
         """
-        return ((2.0 * j + 1.0) / self.rot_symmetry) * np.exp(-self.rot_energy(j) / (constants.k * T))
+        return ((2.0 * j + 1.0) / self.rot_symmetry) * exp(-self.rot_energy(j) / (constants.k * T))
 
     def Z_rot(self, T: float) -> float:
         """Returns the rotational partition function :math:`Z_{rot}(T)`
@@ -393,9 +394,9 @@ class MoleculeSTS(Particle):
             snr = self.num_rot * (self.num_rot + 1.0)
 
             if dimensional:
-                return kT * (1.0 + np.exp(-B * snr) * (-B * snr - 1.0)) / (self.rot_symmetry * self.Z_rot(T) * B)
+                return kT * (1.0 + exp(-B * snr) * (-B * snr - 1.0)) / (self.rot_symmetry * self.Z_rot(T) * B)
             else:
-                return (1.0 + np.exp(-B * snr) * (-B * snr - 1.0)) / (self.rot_symmetry * self.Z_rot(T) * B)
+                return (1.0 + exp(-B * snr) * (-B * snr - 1.0)) / (self.rot_symmetry * self.Z_rot(T) * B)
         else:
             if dimensional:
                 return self._current_rae
@@ -426,11 +427,11 @@ class MoleculeSTS(Particle):
             B = self.rot_const / kT
             snr = self.num_rot * (self.num_rot + 1)
             if dimensional:
-                return (2.0 + np.exp(-B * snr) * (-B * snr * (B * snr + 2) - 2)) * (kT ** 2) / (self.rot_symmetry
-                                                                                                * self.Z_rot(T) * B)
+                return (2.0 + exp(-B * snr) * (-B * snr * (B * snr + 2) - 2)) * (kT ** 2) / (self.rot_symmetry
+                                                                                             * self.Z_rot(T) * B)
             else:
-                return (2.0 + np.exp(-B * snr) * (-B * snr * (B * snr + 2) - 2)) / (self.rot_symmetry
-                                                                                    * self.Z_rot(T) * B)
+                return (2.0 + exp(-B * snr) * (-B * snr * (B * snr + 2) - 2)) / (self.rot_symmetry
+                                                                                 * self.Z_rot(T) * B)
         else:
             if dimensional:
                 return self._current_raesq
@@ -474,7 +475,7 @@ class MoleculeSTS(Particle):
         elif model == '3T':
             return np.sum(np.exp((self.vibr_zero + self.vibr) / (3.0 * constants.k * T)))
 
-    def Z_diss(self, i, T: float, model: str='D6k'):
+    def Z_diss(self, T: float, i, model: str='D6k'):
         """Returns the non-equilibrium factor (which is used in various
         dissociation models) as a function of the temperature T and a parameter U (specified by ``model``) and
         the vibrational level ``i``, which is equal to
@@ -501,14 +502,14 @@ class MoleculeSTS(Particle):
             The non-equilibrium factor
         """
         if model == 'inf':
-            return np.exp((self.vibr[i] + self.vibr_zero) / (T * constants.k))\
-                           * self.Z_vibr_eq(T, 'none') / self.Z_vibr_eq(T, model)
+            return exp((self.vibr[i] + self.vibr_zero) / (T * constants.k))\
+                   * self.Z_vibr_eq(T, 'none') / self.Z_vibr_eq(T, model)
         elif model == 'D6k':
-            return np.exp((self.vibr[i] + self.vibr_zero) * (1.0 / (constants.k * T) + 6.0 / self.diss))\
-                           * self.Z_vibr_eq(T, 'none') / self.Z_vibr_eq(T, model)
+            return exp((self.vibr[i] + self.vibr_zero) * (1.0 / (constants.k * T) + 6.0 / self.diss))\
+                   * self.Z_vibr_eq(T, 'none') / self.Z_vibr_eq(T, model)
         elif model == '3T':
-            return np.exp((self.vibr[i] + self.vibr_zero) / (0.75 * T * constants.k))\
-                           * self.Z_vibr_eq(T, 'none') / self.Z_vibr_eq(T, model)
+            return exp((self.vibr[i] + self.vibr_zero) / (0.75 * T * constants.k))\
+                   * self.Z_vibr_eq(T, 'none') / self.Z_vibr_eq(T, model)
 
 
 class Molecule(MoleculeSTS):
@@ -681,7 +682,11 @@ class Molecule(MoleculeSTS):
         """
         self.num_vibr = self.num_vibr_levels(T, T1, True)
 
-        MoleculeSTS.renorm_sts(self, T)
+        self._current_Z_rot = self.Z_rot(T)
+        self._current_rae = self.avg_rot_energy(T, True)
+        self._current_rae_dimensionless = self.avg_rot_energy(T, False)
+        self._current_raesq = self.avg_rot_energy_sq(T, True)
+        self._current_raesq_dimensionless = self.avg_rot_energy_sq(T, False)
 
         self._current_Z_vibr = self.Z_vibr(T, T1)
         self._current_Z_int = self.Z_int(T, T1)
@@ -701,10 +706,11 @@ class Molecule(MoleculeSTS):
         self._current_vae_i_dimensionless = self.avg_vibr_energy_i(T, T1, False)
 
         a = np.arange(0, self.num_vibr + 1, 1)
-        self._current_v_exp = self.vibr_exp(a, T, T1)
-        self._current_ni = self.ni(a, T, T1, n_c)
+        self._current_v_exp = self.vibr_exp(T, T1, a)
+        self._current_ni = self.ni(T, T1, a, n_c)
         self._current_n = n_c
         self._current_T1 = T1
+        self._current_T = T
 
     def num_vibr_levels(self, T: float, T1: float, true_amt: bool=True) -> int:
         """Returns the amount of vibrational levels (either the maximum one or current one)
@@ -742,7 +748,7 @@ class Molecule(MoleculeSTS):
             else:
                 return self.num_vibr
 
-    def vibr_exp(self, i, T: float, T1: float):
+    def vibr_exp(self, T: float, T1: float, i):
         """Returns the vibrational exponent: :math:`\\exp((-\\varepsilon_{i} - i \\varepsilon_{1}) / kT
         - i \\varepsilon_{1} / kT_{1})`
 
@@ -782,7 +788,7 @@ class Molecule(MoleculeSTS):
             The vibrational partition function
         """
         if (self._current_T != T) or (self._current_T1 != T1):
-            return self.vibr_exp(np.arange(0, self.num_vibr_levels(T, T1, True) + 1, 1), T, T1).sum()
+            return self.vibr_exp(T, T1, np.arange(0, self.num_vibr_levels(T, T1, True) + 1, 1)).sum()
         else:
             return self._current_Z_vibr
 
@@ -829,9 +835,9 @@ class Molecule(MoleculeSTS):
         if (self._current_T != T) or (self._current_T1 != T1):
             a = np.arange(0, self.num_vibr_levels(T, T1, True) + 1, 1)
             if dimensional:
-                return np.dot(self.vibr_exp(a, T, T1), self.vibr[a]) / self.Z_vibr(T, T1)
+                return np.dot(self.vibr_exp(T, T1, a), self.vibr[a]) / self.Z_vibr(T, T1)
             else:
-                return np.dot(self.vibr_exp(a, T, T1), self.vibr[a] / (constants.k * T)) / self.Z_vibr(T, T1)
+                return np.dot(self.vibr_exp(T, T1, a), self.vibr[a] / (constants.k * T)) / self.Z_vibr(T, T1)
         else:
             if dimensional:
                 return self._current_vae
@@ -883,9 +889,9 @@ class Molecule(MoleculeSTS):
         if (self._current_T != T) or (self._current_T1 != T1):
             a = np.arange(0, self.num_vibr_levels(T, T1, True) + 1, 1)
             if dimensional:
-                return np.dot(self.vibr_exp(a, T, T1), np.power(self.vibr[a], 2)) / self.Z_vibr(T, T1)
+                return np.dot(self.vibr_exp(T, T1, a), np.power(self.vibr[a], 2)) / self.Z_vibr(T, T1)
             else:
-                return np.dot(self.vibr_exp(a, T, T1), np.power(self.vibr[a] / (constants.k * T), 2))\
+                return np.dot(self.vibr_exp(T, T1, a), np.power(self.vibr[a] / (constants.k * T), 2))\
                        / self.Z_vibr(T, T1)
         else:
             if dimensional:
@@ -910,7 +916,7 @@ class Molecule(MoleculeSTS):
         """
         if (self._current_T != T) or (self._current_T1 != T1):
             a = np.arange(0, self.num_vibr_levels(T, T1, True) + 1, 1)
-            res = np.dot(self.vibr_exp(a, T, T1), a)
+            res = np.dot(self.vibr_exp(T, T1, a), a)
             return res / self.Z_vibr(T, T1)
         else:
             return self._current_avg_i
@@ -933,7 +939,7 @@ class Molecule(MoleculeSTS):
         """
         if (self._current_T != T) or (self._current_T1 != T1):
             a = np.arange(0, self.num_vibr_levels(T, T1, True) + 1, 1)
-            res = np.dot(self.vibr_exp(a, T, T1), np.power(a, 2))
+            res = np.dot(self.vibr_exp(T, T1, a), np.power(a, 2))
             return res / self.Z_vibr(T, T1)
         else:
             return self._current_avg_i_sq
@@ -962,16 +968,16 @@ class Molecule(MoleculeSTS):
         if (self._current_T != T) or (self._current_T1 != T1):
             a = np.arange(0, self.num_vibr_levels(T, T1, True) + 1, 1)
             if dimensional:
-                return np.dot(a * self.vibr[a], self.vibr_exp(a, T, T1)) / self.Z_vibr(T, T1)
+                return np.dot(a * self.vibr[a], self.vibr_exp(T, T1, a)) / self.Z_vibr(T, T1)
             else:
-                return np.dot(a * self.vibr[a] / (constants.k * T), self.vibr_exp(a, T, T1)) / self.Z_vibr(T, T1)
+                return np.dot(a * self.vibr[a] / (constants.k * T), self.vibr_exp(T, T1, a)) / self.Z_vibr(T, T1)
         else:
             if dimensional:
                 return self._current_vae_i
             else:
                 return self._current_vae_i_dimensionless
 
-    def ni(self, i, T: float, T1: float, n_c: float) -> float:
+    def ni(self, T: float, T1: float, i, n_c: float) -> float:
         """Returns the numeric density of the ``i``-th vibrational level :math:`n_{i}` for the molecular species
 
         Parameters
@@ -991,7 +997,7 @@ class Molecule(MoleculeSTS):
             The numeric density for a given index or set of indices `i`
         """
         if (self._current_T != T) or (self._current_T1 != T1) or (self._current_n != n_c):
-            return n_c * self.vibr_exp(i, T, T1) / self.Z_vibr(T, T1)
+            return n_c * self.vibr_exp(T, T1, i) / self.Z_vibr(T, T1)
         else:
             return self._current_ni[i]
 
@@ -1013,7 +1019,7 @@ class Molecule(MoleculeSTS):
         """
         if (self._current_T != T) or (self._current_T1 != T1):
             a = np.arange(0, self.num_vibr_levels(T, T1, True) + 1, 1)
-            return np.dot(self.vibr[a] - a * self.vibr[1], self.vibr_exp(a, T, T1)) / (constants.k * T * T)
+            return np.dot(self.vibr[a] - a * self.vibr[1], self.vibr_exp(T, T1, a)) / (constants.k * T * T)
         else:
             return self._current_zdt
 
@@ -1036,7 +1042,7 @@ class Molecule(MoleculeSTS):
         """
         if (self._current_T != T) or (self._current_T1 != T1):
             a = np.arange(0, self.num_vibr_levels(T, T1, True) + 1, 1)
-            return self.vibr[1] * np.dot(a, self.vibr_exp(a, T, T1)) / (constants.k * T1 * T1)
+            return self.vibr[1] * np.dot(a, self.vibr_exp(T, T1, a)) / (constants.k * T1 * T1)
         else:
             return self._current_zdt1
 
