@@ -19,13 +19,13 @@ def dUdT(T: float, mixture_components_atoms: list, mixture_components_molecules:
     T : float
         the temperature of the mixture
     mixture_components_atoms : list
-        a list of iterables of the following form, corresponding to the atomic species in the mixture:
+        a list of iterables of the following form, corresponding to the atomic components of the flow:
 
             0. the ``Atom`` class instance
             #. the corresponding numeric density of the atomic species
 
     mixture_components_molecules : list
-        a list of iterables of the following form, corresponding to the molecular species in the mixture:
+        a list of iterables of the following form, corresponding to the molecular components of the flow:
 
             0. the ``Molecule`` class instance
             #. the corresponding numeric density of the molecular species
@@ -84,7 +84,7 @@ def dUdT1(T: float, T1: float, molecule: Molecule, n_molecule: float, mixture_de
 
 def dUdn_atom(T: float, atom: Atom, mixture_density: float) -> float:
     """Calculates the partial derivative of the internal energy of the mixture per unit of mass :math:`U` with respect
-    to the numeric density of an atomic species
+    to the numeric density of an atomic species :math:`n_{c}`
 
     Parameters
     ----------
@@ -106,7 +106,7 @@ def dUdn_atom(T: float, atom: Atom, mixture_density: float) -> float:
 
 def dUdn_molecule(T: float, T1: float, molecule: Molecule, mixture_density: float) -> float:
     """Calculates the partial derivative of the internal energy of the mixture per unit of mass :math:`U` with respect
-    to the numeric density of an atomic species
+    to the numeric density of a molecular species :math:`n_{c}` in the multi-temperature approximation
 
     Parameters
     ----------
